@@ -10,10 +10,7 @@ from ..models import CourseTableManagerV1
 from ..models import RestTableV2, CourseTableManagerV2, SemesterV2
 from ..utils.constants import ERROR_PARAMS, SUCCESS, MSG
 from ..utils.core import config
-from ..utils.data_req import (
-    create_teacher_req, create_student_req, create_section_req, update_section_req, get_device_info,
-    get_section_by_school, get_school_by_id, get_school_by_name, get_school_by_code, create_classroom_req,
-    create_subject_req, update_student_req, update_teacher_req, create_school_req, update_school_req)
+from ..utils.data_req import *
 from ..utils.loggerutils import logging
 
 logger = logging.getLogger(__name__)
@@ -641,3 +638,85 @@ class DataClientV2(DataClient):
         backbone = BackboneV2(school_id)
         backbone.delete_all_table_manager(semester_name)
         return True
+
+
+class DataClientV3(DataClient):
+    @staticmethod
+    def get_teacher_info(params, school_id):
+        """
+        :param params: {"number":"xx", "name":"xx"}
+        :param school_id:
+        :return:
+        """
+        code, data = get_teacher_req(params, school_id)
+        if code:
+            logger.error("Error, query teacher info, Detail: {}".format(data))
+        return data
+
+    def delete_teacher(self, params, school_id):
+        data = self.get_teacher_info(params, school_id)
+        if len(data) > 1:
+            return ERROR_PARAMS, "查询老师信息不唯一"
+        elif len(data) == 1:
+            teacher_id = data[0]['uuid']
+            code, data = delete_teacher_req(teacher_id, school_id)
+            return code, data
+        else:
+            return ERROR_PARAMS, "未查询到老师信息"
+
+    @staticmethod
+    def get_student_info(params, school_id):
+        """
+        :param params: {"number":"xx", "name":"xx", "description":"xx", "section_id":"xx"}
+        :param school_id:
+        :return:
+        """
+        code, data = get_student_req(params, school_id)
+        if code:
+            logger.error("Error, query student info, Detail: {}".format(data))
+        return data
+
+    def delete_student(self, params, school_id):
+        data = self.get_student_info(params, school_id)
+        if len(data) > 1:
+            return ERROR_PARAMS, "查询学生信息不唯一"
+        elif len(data) == 1:
+            student_id = data[0]['uuid']
+            code, data = delete_student_req(student_id, school_id)
+            return code, data
+        else:
+            return ERROR_PARAMS, "未查询到学生信息"
+
+    def delete_school(self, name):
+        code, data = self.get_school_by_name(name)
+        if code:
+            logger.error("Error, query school info, Detail: {}".format(data))
+            return ERROR_PARAMS, data
+        else:
+            school_id = data["uuid"]
+            code, data = delete_school_req(school_id)
+            return code, data
+
+    @staticmethod
+    def get_section_info(params, school_id):
+        """
+        :param params: {"num":"xx", "name":"xx", "grade":"xx"}
+        :param school_id:
+        :return:
+        """
+        code, data = get_section_req(params, school_id)
+        if code:
+            logger.error("Error, query section info, Detail: {}".format(data))
+        return data
+
+    def delete_section(self, params, school_id):
+        section = self.get_section_info(params, school_id)
+        count = section.get("count")
+        if count > 1:
+            return ERROR_PARAMS, "查询班级信息不唯一"
+        elif count == 1:
+            section_id = section["results"][0]["uid"]
+            code, data = delete_section_req(section_id=section_id, school_id=school_id)
+            return code, data
+        else:
+            return ERROR_PARAMS, "未查询到班级信息"
