@@ -28,18 +28,17 @@ class RoomType(object):
 
 
 class Classroom(BaseModel):
-    name = None
-    category = RoomType.TYPE_CLASS
-    seats = 1
-    number = None
-    building = None
-    floor = None
-    section_name = None
-    mode = ModeType.MODE_COMMON
-    extra_info = None
-    school = None
-
     def __init__(self, *args, **kwargs):
+        self.name = None
+        self.category = RoomType.TYPE_CLASS
+        self.seats = 1
+        self.number = None
+        self.building = None
+        self.floor = None
+        self.section_name = None
+        self.mode = ModeType.MODE_COMMON
+        self.extra_info = {}
+        self.school = None
         super(Classroom, self).__init__(*args, **kwargs)
         self.section_id = None
         self.required_filed = ["name", "number", "seats", "category"]
@@ -52,7 +51,8 @@ class Classroom(BaseModel):
                 "num": self.number,
                 "building": self.building,
                 "floor": self.floor,
-                "mode": self.mode}
+                "mode": self.mode,
+                "extra_info": self.extra_info}
         if self.section_id:
             data["section"] = {"uid": self.section_id}
         return data
