@@ -6,7 +6,7 @@ from __future__ import absolute_import, unicode_literals
 
 from .core import config
 from .loggerutils import logging
-from .requestutils import (do_get_request, do_post_request, do_put_request)
+from .requestutils import (do_get_request, do_post_request, do_put_request, do_delete_request)
 
 logger = logging.getLogger(__name__)
 
@@ -236,3 +236,58 @@ def create_subject_req(data, school_id):
     if code:
         logger.error("Error: Request: {}, Detail: {}".format(url, data))
     return code, data
+
+
+def get_section_req(params, school_id):
+    """get section of class card server"""
+    url = "{}/api/class/".format(class_card_server_url())
+    resp = do_get_request(url=url, params=params, token=class_card_server_token(), school_in_header=school_id)
+    code = resp.code
+    data = resp.data.get('data', {}) if not code else resp.msg
+    if code:
+        logger.error("Error: Request: {}, Detail: {}".format(url, data))
+    return code, data
+
+
+def delete_teacher_req(teacher_id, school_id):
+    """ delete teacher from edtech user server"""
+    url = "{}/api/v1/schools/{}/teachers/{}/".format(edtech_server_url(), school_id, teacher_id)
+    resp = do_delete_request(url=url, token=edtech_server_token())
+    code = resp.code
+    data = resp.data.get('data', {}) if not code else resp.msg
+    if code:
+        logger.error("Error: Request: {}, Detail: {}".format(url, data))
+    return code, data
+
+
+def delete_student_req(student_id, school_id):
+    """ delete student from edtech user server"""
+    url = "{}/api/v1/schools/{}/students/{}/".format(edtech_server_url(), school_id, student_id)
+    resp = do_delete_request(url=url, token=edtech_server_token())
+    code = resp.code
+    data = resp.data.get('data', {}) if not code else resp.msg
+    if code:
+        logger.error("Error: Request: {}, Detail: {}".format(url, data))
+    return code, data
+
+
+def delete_section_req(section_id, school_id):
+    """ delete section from edtech user server"""
+    url = "{}/api/v1/schools/{}/sections/{}/".format(edtech_server_url(), school_id, section_id)
+    resp = do_delete_request(url=url, token=edtech_server_token())
+    code = resp.code
+    data = resp.data.get('data', {}) if not code else resp.msg
+    if code:
+        logger.error("Error: Request: {}, Detail: {}".format(url, data))
+    return code, data
+
+
+def delete_school_req(school_id):
+    """ delete school from edtech user server"""
+    url = "{}/api/v1/schools/{}/".format(edtech_server_url(), school_id)
+    resp = do_delete_request(url=url, token=edtech_server_token())
+    code = resp.code
+    data = resp.data.get('data', {}) if not code else resp.msg
+    if code:
+        logger.error("Error: Request: {}, Detail: {}".format(url, data))
+    return code, data
